Mark class

Mark represents a mark or annotation on the canvas.

Constructors

Mark({required Offset position, Offset? endPosition, required int type, bool isFocus = false, List<String>? imagePaths, List<String>? imageLinks, bool isNew = false})
Mark.fromJson(Map<String, dynamic> json)
factory

Properties

endPosition Offset?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
getter/setter pair
imagePaths List<String>?
getter/setter pair
isFocus bool
getter/setter pair
isNew bool
getter/setter pair
position Offset
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int
getter/setter pair

Methods

copyWith({Offset? position, Offset? endPosition, int? type, bool? isFocus, List<String>? imagePaths, List<String>? imageLinks, bool? isNew}) Mark
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited