paint method

  1. @override
void paint(
  1. Canvas canvas,
  2. Size size
)
override

Called whenever the object needs to paint. The given Canvas has its coordinate space configured such that the origin is at the top left of the box. The area of the box is the size of the size argument.

Paint operations should remain inside the given area. Graphical operations outside the bounds may be silently ignored, clipped, or not clipped. It may sometimes be difficult to guarantee that a certain operation is inside the bounds (e.g., drawing a rectangle whose size is determined by user inputs). In that case, consider calling Canvas.clipRect at the beginning of paint so everything that follows will be guaranteed to only draw within the clipped area.

Implementations should be wary of correctly pairing any calls to Canvas.save/Canvas.saveLayer and Canvas.restore, otherwise all subsequent painting on this canvas may be affected, with potentially hilarious but confusing results.

To paint text on a Canvas, use a TextPainter.

To paint an image on a Canvas:

  1. Obtain an ImageStream, for example by calling ImageProvider.resolve on an AssetImage or NetworkImage object.

  2. Whenever the ImageStream's underlying ImageInfo object changes (see ImageStream.addListener), create a new instance of your custom paint delegate, giving it the new ImageInfo object.

  3. In your delegate's paint method, call the Canvas.drawImage, Canvas.drawImageRect, or Canvas.drawImageNine methods to paint the ImageInfo.image object, applying the ImageInfo.scale value to obtain the correct rendering size.

Implementation

@override
void paint(Canvas canvas, Size size) {
  const markRadius = 8.0;

  final paint = Paint();
  final borderPaint = Paint()
    ..color = Colors.green
    ..style = PaintingStyle.stroke
    ..strokeWidth = 3.0;

  // Helper function to draw a focus border
  void drawFocusBorder(Offset center) {
    canvas.drawRect(
      Rect.fromCenter(
        center: center,
        width: 25,
        height: 25,
      ),
      borderPaint,
    );
  }

  for (final mark in marks) {
    if (mark.isNew) {
      paint.color = Colors.red;
    } else {
      paint.color = Colors.teal;
    }

    // To draw a rectangular border around the mark:
    if (mark.isFocus) {
      drawFocusBorder(mark.position);
      if (mark.type == 3 && mark.endPosition != null) {
        drawFocusBorder(mark.endPosition!);
      }
    }

    switch (mark.type) {
      case 0: // Filled circle
        paint.style = PaintingStyle.fill;
        canvas.drawCircle(mark.position, markRadius, paint);
        break;
      case 1: // Stroked circle
        paint.style = PaintingStyle.stroke;
        paint.strokeWidth = 3;
        canvas.drawCircle(mark.position, markRadius, paint);
        break;
      case 2: // Cross
        paint.style = PaintingStyle.stroke;
        paint.strokeWidth = 3;

        // Calculate cross lines based on position and size
        const double halfSize = 8;
        final Offset topLeft =
            mark.position - const Offset(halfSize, halfSize);
        final Offset topRight =
            mark.position + const Offset(halfSize, -halfSize);
        final Offset bottomLeft =
            mark.position + const Offset(-halfSize, halfSize);
        final Offset bottomRight =
            mark.position + const Offset(halfSize, halfSize);

        // Draw the cross
        canvas.drawLine(topLeft, bottomRight, paint);
        canvas.drawLine(topRight, bottomLeft, paint);
        break;
      case 3: // Line
        paint.strokeCap = StrokeCap.round;
        paint.strokeWidth = 4;
        if (mark.endPosition != null) {
          canvas.drawLine(mark.position, mark.endPosition!, paint);
        }
        break;
      case 6:
        if (iconImage != null) {
          final dstRect = Rect.fromCenter(
            center: mark.position,
            width: 40,
            height: 40,
          );
          final srcRect = Rect.fromLTWH(0, 0, iconImage!.width.toDouble(), iconImage!.height.toDouble());

          canvas.drawImageRect(iconImage!, srcRect, dstRect, Paint());
        }
      default:
        break;
    }
  }
}