controller property
A controller to programmatically interact with the marker screen,
such as clearing marks or saving them.
Implementation
final MarkerController? controller;
A controller to programmatically interact with the marker screen,
such as clearing marks or saving them.
final MarkerController? controller;