onMarkFocused property
A callback function that is triggered when an existing mark is focused (e.g., by tapping on it).
Implementation
final Function(Mark)? onMarkFocused;
A callback function that is triggered when an existing mark is focused (e.g., by tapping on it).
final Function(Mark)? onMarkFocused;