SideBarItem class

Constructors

SideBarItem({int? type, IconData? icon, String? customCanvasIcon, bool isAction = false, bool isScratch = false})
SideBarItem.scratch()

Properties

customCanvasIcon String?
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
final
isAction bool
final
isScratch bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int?
final

Methods

copyWith({int? type, IconData? icon, String? customCanvasIcon, bool? isScratch, bool? isAction}) SideBarItem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited