AppUtils class
Constructors
- AppUtils()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
allSidebarItems
→ Map<
SidebarIconsEnum, SideBarItem> -
final
Static Methods
-
getClosestPointForLine(
Offset tap, Offset start, Offset end) → Offset -
getImageDimensions(
String image) → Future< Image> -
getMarkIfExist(
List< Mark> marks, Offset tapPosition) → Mark? -
getSidebarItems(
{List< SidebarIconsEnum> ? iconsEnums, String? customCanvasIcon}) → List<SideBarItem> -
isMarkPositionNear(
Offset targetedPosition, Offset tapPosition) → bool -
loadUiImage(
String assetPath) → Future< Image>