MarkerScreen class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MarkerScreen
Constructors
-
MarkerScreen({Key? key, required String image, List<
Mark> ? defaultMarks, dynamic onMarkAdded(Mark)?, dynamic onMarkFocused(Mark)?, dynamic onMarkImagesClick(List<String> )?, bool? showImages, MarkerController? controller, List<SidebarIconsEnum> ? sidebarIconsEnums, String? customCanvasIcon})
Properties
- controller → MarkerController?
-
A
controllerto programmatically interact with the marker screen, such as clearing marks or saving them.final - customCanvasIcon → String?
-
final
-
defaultMarks
→ List<
Mark> ? -
A list of predefined marks to be displayed on the image initially.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → String
-
The
imageon which marks will be added. This should be a URL or a local asset path.final - key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onMarkAdded → dynamic Function(Mark)?
-
A callback function that is triggered when a new mark is added to the image.
final
- onMarkFocused → dynamic Function(Mark)?
-
A callback function that is triggered when an existing mark is focused (e.g., by tapping on it).
final
-
onMarkImagesClick
→ dynamic Function(List<
String> )? -
A callback function that is triggered when the images associated with a mark are clicked.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showImages → bool?
-
A boolean to control the visibility of images associated with a mark.
final
-
To show/hide the icons from the sidebar
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MarkerScreen> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited